==> brmo-stufbg204-1.6.3p1-sources.jar: nl/egem/stuf/stuf0204/DatumMetIndicatorKerngegeven.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DatumMetIndicatorKerngegeven complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DatumMetIndicatorKerngegeven">
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.egem.nl/StUF/StUF0204>DatumMetIndicator">
 *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DatumMetIndicatorKerngegeven")
public class DatumMetIndicatorKerngegeven
    extends DatumMetIndicator
{

    @XmlAttribute(name = "kerngegeven")
    protected Boolean kerngegeven;

    /**
     * Gets the value of the kerngegeven property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isKerngegeven() {
        if (kerngegeven == null) {
            return true;
        } else {
            return kerngegeven;
        }
    }

    /**
     * Sets the value of the kerngegeven property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setKerngegeven(Boolean value) {
        this.kerngegeven = value;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/stuf0204/DatumMetIndicatorKerngegeven.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DatumMetIndicatorKerngegeven complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DatumMetIndicatorKerngegeven"&gt;
 *   &lt;simpleContent&gt;
 *     &lt;extension base="&lt;http://www.egem.nl/StUF/StUF0204&gt;DatumMetIndicator"&gt;
 *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/simpleContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DatumMetIndicatorKerngegeven")
public class DatumMetIndicatorKerngegeven
    extends DatumMetIndicator
{

    @XmlAttribute(name = "kerngegeven")
    protected Boolean kerngegeven;

    /**
     * Gets the value of the kerngegeven property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isKerngegeven() {
        if (kerngegeven == null) {
            return true;
        } else {
            return kerngegeven;
        }
    }

    /**
     * Sets the value of the kerngegeven property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setKerngegeven(Boolean value) {
        this.kerngegeven = value;
    }

}
